@@ -1,6 +1,7 @@
 from django.contrib import admin
 
-from publisher.models import Buzz, Facebook, Mobile, SocialBookmark, Twitter, Web
+from publisher.models import Buzz, Facebook, Mobile, SocialBookmark, Twitter, \
+        Web
 
 admin.site.register(Buzz)
 admin.site.register(Facebook)
